"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _axios = _interopRequireDefault(require("axios"));

var _upload2 = _interopRequireDefault(require("ant-design-vue/es/upload"));

var _icon = _interopRequireDefault(require("ant-design-vue/es/icon"));

var _modal = _interopRequireDefault(require("ant-design-vue/es/modal"));

var _types = _interopRequireDefault(require("./types"));

require("./style.less");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

var _default = {
  name: 'EFileUpload',
  props: _types["default"],
  data: function data() {
    return {
      fileList: [],
      // 已经上传的文件列表（受控）
      previewVisible: false,
      // 预览模态是否显示
      previewImage: '',
      // 当前预览的图片
      loading: false,
      // 当前上传是否进行中，如果是进行中则会展示loading的icon
      disabled: true,
      // 是否禁用
      formData: {},
      fileUrlList: undefined // change事件传出的value

    };
  },
  watch: {
    fileList: function fileList(newVal, oldVal) {
      // const url = newVal && newVal.length > 0 ? newVal[0].url : ''
      if (this.maxCount > 1) {
        // 超出一个数据就
        this.$data.fileUrlList = newVal.map(function (item) {
          return item.url;
        });
      } else {
        if (newVal.length > 0) {
          this.$data.fileUrlList = newVal[0].url;
        } else {
          this.$data.fileUrlList = undefined;
        }
      }

      this.$emit('input', this.$data.fileUrlList);
      this.$emit('change', this.$data.fileUrlList);
    },
    ossClient: function ossClient(newVal) {
      if (newVal) {
        this.$data.disabled = false;

        this._handleExistedFileList();
      }
    },
    value: function value(newVal, oldVal) {
      var newValStr = JSON.stringify(newVal);
      var oldValStr = JSON.stringify(oldVal);

      if (Object.keys(this.ossClient).length > 0 && newValStr !== oldValStr && newVal !== this.$data.fileUrlList) {
        this.$data.disabled = false;

        this._handleExistedFileList();
      }
    }
  },
  computed: {
    // ...mapState({
    //   ossClient: state => state.oss.ossClient // 当前store中的ossClient
    // }),
    // ossClient() {
    // return this.$store.getters.oss.ossClient
    // },
    desc: function desc() {
      return this.$data.disabled ? '初始化中...' : this.$props.description;
    },
    action: function action() {
      return "http://".concat(this.ossClient.bucket, ".").concat(this.ossClient.endPoint);
    }
  },
  inject: ['resetOssClient'],
  created: function created() {
    if (Object.keys(this.ossClient).length > 0) {
      this.$data.disabled = false;

      this._handleExistedFileList();
    } else {
      this._resetOssClient();
    }
  },
  methods: {
    /**
     * 重新初始化oss对象
     * @private
     */
    _resetOssClient: function _resetOssClient() {
      if (this.resetOssClient) {
        this.resetOssClient();
      } else {
        console.error('Can Not dispatch inject method "resetOssClient",Please Provide this in your project！');
      }
    },

    /**
     * 处理预设的图片
     */
    _handleExistedFileList: function _handleExistedFileList() {
      if (this.value) {
        // this.fileList.splice(0)
        var newFileList = []; // 根据value的类型来做处理

        var valueArr = this.value;

        if (typeof this.value === 'string') {
          valueArr = [this.value];
        }

        valueArr.forEach(function (name, index) {
          // const name = this.value
          // const targetUrl = this.ossClient.signatureUrl(name)
          var targetUrl = name;
          newFileList.push({
            url: targetUrl,
            status: 'done',
            uid: new Date().getTime() + index,
            thumbUrl: targetUrl,
            name: name
          });
        });
        this.fileList = newFileList; // const name = this.value
        // // const targetUrl = this.ossClient.signatureUrl(name)
        // const targetUrl = name
        // this.fileList.push({
        //   url: targetUrl,
        //   status: 'done',
        //   uid: new Date().getTime(),
        //   thumbUrl: targetUrl,
        //   name: name
        // })
      } else {
        if (this.fileList.length > 0) {
          // 如果图片列表有数据则清空
          this.fileList = [];
        }
      }
    },

    /**
     * 处理预览回调
     * @param file 当前点击预览的文件对象
     * @private
     */
    _handlePreview: function _handlePreview(file) {
      this.previewImage = file.thumbUrl;
      this.previewVisible = true;
    },

    /**
     * 处理业务变更
     * @param fileList 已经上传的文件列表
     * @private
     */
    _handleChange: function _handleChange(_ref) {
      var file = _ref.file;

      if (file.status === 'removed') {
        var index = this.fileList.findIndex(function (item) {
          return item.uid === file.uid;
        });

        if (index !== -1) {
          this.fileList.splice(index, 1);
        }
      } else if (file.status === 'uploading') {
        this.$data.loading = true;
      } else if (file.status === 'done') {
        var name = file.name;
        var targetUrl = "".concat(this.action, "/").concat(this.$data.formData.key);
        this.fileList.push({
          url: targetUrl,
          status: 'done',
          uid: new Date().getTime(),
          thumbUrl: targetUrl,
          name: name
        });
        this.$data.loading = false;
        this.$message.success('上传成功');
      }
    },

    /**
     * 取消预览
     * @private
     */
    _handleCancelPreview: function _handleCancelPreview() {
      this.previewVisible = false;
    },

    /**
     * 上传前的处理函数，处理支持的文件类型及大小
     * @param file
     * @return {boolean|boolean}
     * @private
     */
    _handleBeforeUpload: function _handleBeforeUpload(file) {
      var isJpgOrPng = file.type === 'image/jpeg' || file.type === 'image/png';

      if (!isJpgOrPng) {
        this.$message.error('只允许jpeg、png格式图片');
      }

      var isLt2M = file.size / 1024 / 1024 < 2;

      if (!isLt2M) {
        this.$message.error('图片大小不能超过2M');
      }

      if (isJpgOrPng && isLt2M) {
        this.$data.formData = _extends({}, this.ossClient, {
          name: file.name,
          key: this.ossClient.dir + '/' + new Date().getTime() + '.png'
        });
        delete this.$data.formData.dir;
        delete this.$data.formData.endPoint;
        delete this.$data.formData.bucket;
        return true;
      }
    },

    /**
     * 自定义处理上传逻辑函数
     * @param file
     * @private
     */
    _handleCustomRequest: function _handleCustomRequest(file) {
      this._upload(file.file);
    },

    /**
     * 上传
     * @param file
     * @private
     */
    _upload: function _upload(file) {
      var _this = this;

      this.loading = true;
      var data = new FormData();

      for (var key in this.$data.formData) {
        data.append(key, this.$data.formData[key]);
      }

      data.append('file', file);

      var instance = _axios["default"].create();

      instance.defaults.headers = {
        'Content-Type': 'multipart/form-data'
      };
      instance.defaults.baseURL = this.action;
      instance.request({
        method: 'post',
        data: data
      }).then(function () {
        var name = file.name; // const targetUrl = client.signatureUrl(name)

        var targetUrl = "".concat(_this.action, "/").concat(_this.$data.formData.key);

        _this.fileList.push({
          url: targetUrl,
          status: 'done',
          uid: new Date().getTime(),
          thumbUrl: targetUrl,
          name: name
        });

        _this.$message.success('上传成功');
      })["catch"](function (err) {
        _this.$message.error('上传失败');

        if (err.response.status === 403 || err.response.status === '403') {
          // 这里要考虑是不是真的是这样取错误码的
          _this._resetOssClient();
        }
      })["finally"](function () {
        _this.loading = false;
      });
    }
  },
  render: function render() {
    var h = arguments[0];
    var _this$$data = this.$data,
        fileList = _this$$data.fileList,
        formData = _this$$data.formData,
        disabled = _this$$data.disabled,
        loading = _this$$data.loading,
        previewVisible = _this$$data.previewVisible,
        previewImage = _this$$data.previewImage;
    var maxCount = this.$props.maxCount;
    return h("div", [h(_upload2["default"], {
      attrs: {
        listType: "picture-card",
        fileList: fileList,
        data: formData,
        disabled: disabled,
        beforeUpload: this._handleBeforeUpload,
        customRequest: this._handleCustomRequest
      },
      on: {
        "preview": this._handlePreview,
        "change": this._handleChange
      }
    }, [fileList.length < maxCount ? h("div", [h(_icon["default"], {
      attrs: {
        type: loading ? 'loading' : 'plus'
      }
    }), h("div", {
      attrs: {
        className: "ant-upload-text"
      }
    }, [this.desc])]) : null]), h(_modal["default"], {
      attrs: {
        visible: previewVisible,
        footer: null
      },
      on: {
        "cancel": this._handleCancelPreview
      }
    }, [h("img", {
      attrs: {
        alt: "example",
        src: previewImage
      },
      style: "width: 100%"
    })])]);
  }
};
exports["default"] = _default;